UpdateConnection

Struct UpdateConnection 

pub struct UpdateConnection<'connection> { /* private fields */ }

Implementations

Source

impl<'connection> UpdateConnection<'connection>

pub fn savepoint<T, F>(&mut self, f: F) -> Result<T, DbError>
where F: FnOnce(&mut UpdateConnection<'connection>) -> Result<T, DbError>,

Methods from Deref<Target = Connection>

pub fn raw(&self) -> *mut sqlite3

pub fn execute_batch(&self, sql: &str) -> Result<(), DbError>

pub fn execute(&self, sql: &str, values: &[&dyn ToSql]) -> Result<(), DbError>

pub fn execute_named( &self, sql: &str, values: &[(&str, &dyn ToSql)], ) -> Result<(), DbError>

pub fn prepare(&self, sql: &str) -> Result<Statement<'_>, DbError>

pub fn prepare_cached(&self, sql: &str) -> Result<CachedStatement<'_>, DbError>

pub fn query_one<T, F>( &self, sql: &str, values: &[&dyn ToSql], f: F, ) -> Result<T, DbError>
where F: FnOnce(&Row<'_>) -> Result<T, DbError>,

pub fn query_one_named<T, F>( &self, sql: &str, values: &[(&str, &dyn ToSql)], f: F, ) -> Result<T, DbError>
where F: FnOnce(&Row<'_>) -> Result<T, DbError>,

pub fn query_row<T, F>( &self, sql: &str, values: &[&dyn ToSql], f: F, ) -> Result<T, DbError>
where F: FnOnce(&Row<'_>) -> Result<T, DbError>,

Runs a single-row query.

This is a rusqlite-style alias for Connection::query_one.

pub fn query_row_named<T, F>( &self, sql: &str, values: &[(&str, &dyn ToSql)], f: F, ) -> Result<T, DbError>
where F: FnOnce(&Row<'_>) -> Result<T, DbError>,

Runs a single-row query with named parameters.

This is a rusqlite-style alias for Connection::query_one_named.

pub fn query_optional<T, F>( &self, sql: &str, values: &[&dyn ToSql], f: F, ) -> Result<Option<T>, DbError>
where F: FnOnce(&Row<'_>) -> Result<T, DbError>,

pub fn query_optional_named<T, F>( &self, sql: &str, values: &[(&str, &dyn ToSql)], f: F, ) -> Result<Option<T>, DbError>
where F: FnOnce(&Row<'_>) -> Result<T, DbError>,

pub fn query_all<T, F>( &self, sql: &str, values: &[&dyn ToSql], f: F, ) -> Result<Vec<T>, DbError>
where F: FnMut(&Row<'_>) -> Result<T, DbError>,

pub fn query_all_named<T, F>( &self, sql: &str, values: &[(&str, &dyn ToSql)], f: F, ) -> Result<Vec<T>, DbError>
where F: FnMut(&Row<'_>) -> Result<T, DbError>,

pub fn query_map<T, F>( &self, sql: &str, values: &[&dyn ToSql], f: F, ) -> Result<Vec<T>, DbError>
where F: FnMut(&Row<'_>) -> Result<T, DbError>,

Maps all rows into a Vec<T>.

Unlike rusqlite::Statement::query_map, this returns a collected Vec<T>, not an iterator. That keeps the prepared statement lifetime inside one synchronous canister message.

pub fn query_map_named<T, F>( &self, sql: &str, values: &[(&str, &dyn ToSql)], f: F, ) -> Result<Vec<T>, DbError>
where F: FnMut(&Row<'_>) -> Result<T, DbError>,

Maps all rows into a Vec<T> using named parameters.

Unlike rusqlite::Statement::query_map, this returns a collected Vec<T>, not an iterator. That keeps the prepared statement lifetime inside one synchronous canister message.

pub fn exists(&self, sql: &str, values: &[&dyn ToSql]) -> Result<bool, DbError>

pub fn query_scalar<T: FromColumn>( &self, sql: &str, values: &[&dyn ToSql], ) -> Result<T, DbError>

pub fn query_scalar_named<T: FromColumn>( &self, sql: &str, values: &[(&str, &dyn ToSql)], ) -> Result<T, DbError>

pub fn query_optional_scalar<T: FromColumn>( &self, sql: &str, values: &[&dyn ToSql], ) -> Result<Option<T>, DbError>

pub fn query_optional_string_text( &self, sql: &str, value: &str, ) -> Result<Option<String>, DbError>

pub fn query_optional_scalar_named<T: FromColumn>( &self, sql: &str, values: &[(&str, &dyn ToSql)], ) -> Result<Option<T>, DbError>

pub fn query_column<T: FromColumn>( &self, sql: &str, values: &[&dyn ToSql], ) -> Result<Vec<T>, DbError>

pub fn query_column_named<T: FromColumn>( &self, sql: &str, values: &[(&str, &dyn ToSql)], ) -> Result<Vec<T>, DbError>